@@ -539,6 +539,24 @@ class Grammar extends BaseGrammar
         return '('.$columns.') '.$where['operator'].' ('.$values.')';
     }
 
+    /**
+     * Compile a "where JSON boolean" clause.
+     *
+     * @param  \Illuminate\Database\Query\Builder  $query
+     * @param  array  $where
+     * @return string
+     */
+    protected function whereJsonBoolean(Builder $query, $where)
+    {
+        $column = $this->wrapJsonBooleanSelector($where['column']);
+
+        $value = $this->wrapJsonBooleanValue(
+            $this->parameter($where['value'])
+        );
+
+        return $column.' '.$where['operator'].' '.$value;
+    }
+
     /**
      * Compile a "where JSON contains" clause.
      *
@@ -715,9 +733,7 @@ class Grammar extends BaseGrammar
     protected function compileOrdersToArray(Builder $query, $orders)
     {
         return array_map(function ($order) {
-            return ! isset($order['sql'])
-                        ? $this->wrap($order['column']).' '.$order['direction']
-                        : $order['sql'];
+            return $order['sql'] ?? $this->wrap($order['column']).' '.$order['direction'];
         }, $orders);
     }
 
@@ -856,6 +872,18 @@ class Grammar extends BaseGrammar
         return "insert into $table ($columns) values $parameters";
     }
 
+    /**
+     * Compile an insert ignore statement into SQL.
+     *
+     * @param  \Illuminate\Database\Query\Builder  $query
+     * @param  array  $values
+     * @return string
+     */
+    public function compileInsertOrIgnore(Builder $query, array $values)
+    {
+        throw new RuntimeException('This database engine does not support inserting while ignoring errors.');
+    }
+
     /**
      * Compile an insert and get ID statement into SQL.
      *
@@ -926,7 +954,7 @@ class Grammar extends BaseGrammar
      */
     public function prepareBindingsForUpdate(array $bindings, array $values)
     {
-        $cleanBindings = Arr::except($bindings, ['join', 'select']);
+        $cleanBindings = Arr::except($bindings, ['select', 'join']);
 
         return array_values(
             array_merge($bindings['join'], $values, Arr::flatten($cleanBindings))
@@ -954,7 +982,9 @@ class Grammar extends BaseGrammar
      */
     public function prepareBindingsForDelete(array $bindings)
     {
-        return Arr::flatten($bindings);
+        return Arr::flatten(
+            Arr::except($bindings, 'select')
+        );
     }
 
     /**
@@ -1053,6 +1083,28 @@ class Grammar extends BaseGrammar
         throw new RuntimeException('This database engine does not support JSON operations.');
     }
 
+    /**
+     * Wrap the given JSON selector for boolean values.
+     *
+     * @param  string  $value
+     * @return string
+     */
+    protected function wrapJsonBooleanSelector($value)
+    {
+        return $this->wrapJsonSelector($value);
+    }
+
+    /**
+     * Wrap the given JSON boolean value.
+     *
+     * @param  string  $value
+     * @return string
+     */
+    protected function wrapJsonBooleanValue($value)
+    {
+        return $value;
+    }
+
     /**
      * Split the given JSON selector into the field and the optional path and wrap them separately.
      *
@@ -1065,7 +1117,7 @@ class Grammar extends BaseGrammar
 
         $field = $this->wrap($parts[0]);
 
-        $path = count($parts) > 1 ? ', '.$this->wrapJsonPath($parts[1]) : '';
+        $path = count($parts) > 1 ? ', '.$this->wrapJsonPath($parts[1], '->') : '';
 
         return [$field, $path];
     }
@@ -1074,11 +1126,14 @@ class Grammar extends BaseGrammar
      * Wrap the given JSON path.
      *
      * @param  string  $value
+     * @param  string  $delimiter
      * @return string
      */
-    protected function wrapJsonPath($value)
+    protected function wrapJsonPath($value, $delimiter = '->')
     {
-        return '\'$."'.str_replace('->', '"."', $value).'"\'';
+        $value = preg_replace("/([\\\\]+)?\\'/", "\\'", $value);
+
+        return '\'$."'.str_replace($delimiter, '"."', $value).'"\'';
     }
 
     /**
